import { ZodSchema } from "zod";
import { respondWithError } from "../utils/error.js";
async function setupLoader({ loaderArgs, querySchema, load, paramSchema, middleware }) {
    const params = paramSchema ? paramSchema.parse(loaderArgs.params) : undefined;
    const query = querySchema ? querySchema.parse(loaderArgs.request) : undefined;
    const loadArgs = {
        request: loaderArgs.request,
        context: loaderArgs.context,
        ...(params && { params }),
        ...(query && { query })
    };
    const middlewareResult = middleware ? await middleware(loadArgs) : undefined;
    try {
        return await load({ ...loadArgs, ...middlewareResult });
    }
    catch (thrownValue) {
        if (thrownValue instanceof Response) {
            throw thrownValue;
        }
        throw respondWithError(null, {
            message: thrownValue instanceof Error ? thrownValue.message : "unknown_error",
            code: 500
        });
    }
}
export { setupLoader };
//# sourceMappingURL=setup-loader.server.js.map